@@ -52,6 +52,7 @@ int64_t minfree = (10 * 1024 *1024), maxfree = 0;
 size_t swapsize = (32 * 1024 * 1024);
 char *swapdir = "/var/tmp";
 int max_inactive_swaps = 5;
+int include_cache_mem = 1;
 
 typedef struct {
 	char *pathname;
@@ -114,7 +115,10 @@ int64_t swapd_get_free_mem(void) {
 		return(-1);
 	}
 
-	retval = meminfo->free + meminfo->cache + swapinfo->free;
+	retval = meminfo->free + swapinfo->free;
+	if (include_cache_mem) {
+		retval += meminfo->cache;
+	}
 
 	return(retval);
 #else
@@ -143,7 +147,7 @@ int64_t swapd_get_free_mem(void) {
 		meminfo_part = strtoull(buf_whole, NULL, 10) * 1024;
 		if (strcmp(buf_part, "MemFree") == 0 ||
 		    strcmp(buf_part, "Buffers") == 0 ||
-		    strcmp(buf_part, "Cached") == 0 ||
+		    (strcmp(buf_part, "Cached") == 0 && include_cache_mem) ||
 		    strcmp(buf_part, "SwapFree") == 0) {
 			meminfo += meminfo_part;
 		}
@@ -376,6 +380,8 @@ int swapd_process_config_line(const char *cmd) {
 		max_inactive_swaps = argbuf_int[1];
 	} else if (strcasecmp(argbuf[0], "swapdir") == 0 && argc == 2) {
 		swapdir = strdup(argbuf[1]);
+	} else if (strcasecmp(argbuf[0], "include_cache") == 0 && argc == 2) {
+		include_cache_mem = !strcasecmp(argbuf[1], "yes");
 	} else {
 		PRINTERR("Unknown command: %s/%i", argbuf[0], argc);
 	}
